@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02139, USA.
  */
 
 #include "config.h"
@@ -33,8 +33,6 @@
 #include <X11/extensions/Xrender.h>
 #endif
 
-static void bacon_resize_class_init	(BaconResizeClass *klass);
-static void bacon_resize_init		(BaconResize *ggo);
 static void bacon_resize_set_property	(GObject *object,
 					 guint property_id,
 					 const GValue *value,
@@ -220,16 +218,16 @@ bacon_resize_resize (BaconResize *resize)
 	gboolean found = FALSE;
 	GdkWindow *root;
 	GdkScreen *screen;
-	Display *Display;
+	Display *xdisplay;
 
 	g_return_if_fail (GTK_IS_WIDGET (resize->priv->video_widget));
 	g_return_if_fail (GTK_WIDGET_REALIZED (resize->priv->video_widget));
 
-	Display = GDK_DRAWABLE_XDISPLAY (resize->priv->video_widget->window);
-	if (Display == NULL)
+	xdisplay = GDK_DRAWABLE_XDISPLAY (resize->priv->video_widget->window);
+	if (xdisplay == NULL)
 		return;
 
-	XLockDisplay (Display);
+	XLockDisplay (xdisplay);
 
 	screen = gtk_widget_get_screen (resize->priv->video_widget);
 	root = gdk_screen_get_root_window (screen);
@@ -238,7 +236,7 @@ bacon_resize_resize (BaconResize *resize)
 	if (gdk_screen_get_n_monitors (screen) > 1)
 		goto bail;
 
-	res = XF86VidModeGetModeLine (Display, GDK_SCREEN_XNUMBER (screen), &dotclock, &modeline);
+	res = XF86VidModeGetModeLine (xdisplay, GDK_SCREEN_XNUMBER (screen), &dotclock, &modeline);
 	if (!res)
 		goto bail;
 
@@ -252,7 +250,7 @@ bacon_resize_resize (BaconResize *resize)
 	gdk_error_trap_push ();
 
 	/* Find the XRandR mode that corresponds to the real size */
-	resize->priv->xr_screen_conf = XRRGetScreenInfo (Display, GDK_WINDOW_XWINDOW (root));
+	resize->priv->xr_screen_conf = XRRGetScreenInfo (xdisplay, GDK_WINDOW_XWINDOW (root));
 	xr_sizes = XRRConfigSizes (resize->priv->xr_screen_conf, &xr_nsize);
 	resize->priv->xr_original_size = XRRConfigCurrentConfiguration (resize->priv->xr_screen_conf, &(resize->priv->xr_current_rotation));
 	if (gdk_error_trap_pop ()) {
@@ -271,7 +269,7 @@ bacon_resize_resize (BaconResize *resize)
 		goto bail;
 
 	gdk_error_trap_push ();
-	XRRSetScreenConfig (Display,
+	XRRSetScreenConfig (xdisplay,
 			resize->priv->xr_screen_conf,
 			GDK_WINDOW_XWINDOW (root),
 			(SizeID) i,
@@ -284,7 +282,7 @@ bacon_resize_resize (BaconResize *resize)
 		resize->priv->resized = TRUE;
 
 bail:
-	XUnlockDisplay (Display);
+	XUnlockDisplay (xdisplay);
 #endif /* HAVE_XVIDMODE */
 }
 
@@ -296,7 +294,7 @@ bacon_resize_restore (BaconResize *resize)
 	XF86VidModeModeLine modeline;
 	GdkWindow *root;
 	GdkScreen *screen;
-	Display *Display;
+	Display *xdisplay;
 
 	g_return_if_fail (GTK_IS_WIDGET (resize->priv->video_widget));
 	g_return_if_fail (GTK_WIDGET_REALIZED (resize->priv->video_widget));
@@ -306,15 +304,15 @@ bacon_resize_restore (BaconResize *resize)
 	if (resize->priv->xr_screen_conf == NULL)
 		return;
 
-	Display = GDK_DRAWABLE_XDISPLAY (resize->priv->video_widget->window);
-	if (Display == NULL)
+	xdisplay = GDK_DRAWABLE_XDISPLAY (resize->priv->video_widget->window);
+	if (xdisplay == NULL)
 		return;
 
-	XLockDisplay (Display);
+	XLockDisplay (xdisplay);
 
 	screen = gtk_widget_get_screen (resize->priv->video_widget);
 	root = gdk_screen_get_root_window (screen);
-	res = XF86VidModeGetModeLine (Display, GDK_SCREEN_XNUMBER (screen), &dotclock, &modeline);
+	res = XF86VidModeGetModeLine (xdisplay, GDK_SCREEN_XNUMBER (screen), &dotclock, &modeline);
 	if (!res)
 		goto bail;
 
@@ -326,7 +324,7 @@ bacon_resize_restore (BaconResize *resize)
 		goto bail;
 
 	gdk_error_trap_push ();
-	XRRSetScreenConfig (Display,
+	XRRSetScreenConfig (xdisplay,
 			resize->priv->xr_screen_conf,
 			GDK_WINDOW_XWINDOW (root),
 			resize->priv->xr_original_size,
@@ -342,7 +340,7 @@ bacon_resize_restore (BaconResize *resize)
 	resize->priv->xr_screen_conf = NULL;
 
 bail:
-	XUnlockDisplay (Display);
+	XUnlockDisplay (xdisplay);
 #endif
 }
 
