@@ -62,6 +62,11 @@ totem_statusbar_init (TotemStatusbar *statusbar)
   statusbar->time = 0;
   statusbar->length = -1;
 
+#if GTK_CHECK_VERSION (2, 19, 1)
+  hbox = gtk_statusbar_get_message_area (gstatusbar);
+  gtk_box_set_child_packing (GTK_BOX (hbox), gstatusbar->label,
+			     FALSE, FALSE, 0, GTK_PACK_START);
+#else
   hbox = gtk_hbox_new (FALSE, SPACING);
 
   /* Widget surgery */
@@ -71,6 +76,7 @@ totem_statusbar_init (TotemStatusbar *statusbar)
   g_object_unref (gstatusbar->label);
   gtk_container_add (GTK_CONTAINER (gstatusbar->frame), hbox);
   gtk_widget_show (hbox);
+#endif
 
   gtk_label_set_ellipsize (GTK_LABEL (gstatusbar->label), FALSE);
 
